==> jc-1.4.0.tar.gz: polyglot/ext/jl/ast/TypeNode__5fc.h <==
// public abstract class polyglot.ext.jl.ast.TypeNode_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc
// @dep_class baac4ebe50326f05 polyglot_ext_jl_ast_TypeNode__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_Node__5fc

#include "polyglot/ext/jl/ast/Node__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_TypeNode__5fc_H_
#define _JC_polyglot_ext_jl_ast_TypeNode__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_TypeNode$object;
struct _jc_polyglot_types_Qualifier$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_PrettyPrinter$object;
struct _jc_polyglot_visit_TypeBuilder$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_refs	_jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$refs	_jc_polyglot_ext_jl_ast_TypeNode__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$nonrefs	_jc_polyglot_ext_jl_ast_TypeNode__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object	_jc_polyglot_ext_jl_ast_TypeNode__5fc$object;

typedef const struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$vmethods	_jc_polyglot_ext_jl_ast_TypeNode__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$vtable	_jc_polyglot_ext_jl_ast_TypeNode__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$vtype	_jc_polyglot_ext_jl_ast_TypeNode__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_TypeNode__5fc$method$_init$02a94c1d4b5cc142(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_polyglot_util_Position$object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_ast_TypeNode__5fc$method$buildTypes$df90664105e3e235(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_polyglot_visit_TypeBuilder$object *);
extern void _jc_polyglot_ext_jl_ast_TypeNode__5fc$method$prettyPrint$323ca37cb40f93d3(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_TypeNode__5fc$method$qualifier$06dc7ae4d27ad6a5(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_ast_TypeNode__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_TypeNode__5fc$method$type$b7282830a20ab2a3(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_TypeNode__5fc$method$type$91eb2e23e16df17f(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_TypeNode__5fc$method_info$buildTypes$df90664105e3e235;
extern _jc_method _jc_polyglot_ext_jl_ast_TypeNode__5fc$method_info$prettyPrint$323ca37cb40f93d3;
extern _jc_method _jc_polyglot_ext_jl_ast_TypeNode__5fc$method_info$qualifier$06dc7ae4d27ad6a5;
extern _jc_method _jc_polyglot_ext_jl_ast_TypeNode__5fc$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_ext_jl_ast_TypeNode__5fc$method_info$type$b7282830a20ab2a3;
extern _jc_method _jc_polyglot_ext_jl_ast_TypeNode__5fc$method_info$type$91eb2e23e16df17f;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$vmethods {
	struct _jc_object	*(*buildTypes$df90664105e3e235)(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_polyglot_visit_TypeBuilder$object *);
	void	(*prettyPrint$323ca37cb40f93d3)(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *);
	struct _jc_object	*(*qualifier$06dc7ae4d27ad6a5)(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *);
	struct _jc_object	*(*type$b7282830a20ab2a3)(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *);
	struct _jc_object	*(*type$91eb2e23e16df17f)(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_TypeNode__5fc$vmethods	polyglot_ext_jl_ast_TypeNode__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_TypeNode__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_refs {
	struct _jc_object	*type;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$refs {
    _jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_refs	polyglot_ext_jl_ast_TypeNode__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_nonrefs	polyglot_ext_jl_ast_TypeNode__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object {
	_jc_polyglot_ext_jl_ast_TypeNode__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_TypeNode__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_TypeNode__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_TypeNode__5fc$vtype _jc_polyglot_ext_jl_ast_TypeNode__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_TypeNode__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_TypeNode__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_TypeNode__5fc_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/ast/TypeNode__5fc.h <==
// public abstract class polyglot.ext.jl.ast.TypeNode_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc
// @dep_class baac4ebe50326f05 polyglot_ext_jl_ast_TypeNode__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_Node__5fc

#include "polyglot/ext/jl/ast/Node__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_TypeNode__5fc_H_
#define _JC_polyglot_ext_jl_ast_TypeNode__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_ast_TypeNode$object;
struct _jc_polyglot_types_Qualifier$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_util_CodeWriter$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_PrettyPrinter$object;
struct _jc_polyglot_visit_TypeBuilder$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_refs	_jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$refs	_jc_polyglot_ext_jl_ast_TypeNode__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$nonrefs	_jc_polyglot_ext_jl_ast_TypeNode__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object	_jc_polyglot_ext_jl_ast_TypeNode__5fc$object;

typedef const struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$vmethods	_jc_polyglot_ext_jl_ast_TypeNode__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$vtable	_jc_polyglot_ext_jl_ast_TypeNode__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$vtype	_jc_polyglot_ext_jl_ast_TypeNode__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_TypeNode__5fc$method$_init$02a94c1d4b5cc142(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_polyglot_util_Position$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_ext_jl_ast_TypeNode__5fc$method$buildTypes$df90664105e3e235(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_polyglot_visit_TypeBuilder$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_ast_TypeNode__5fc$method$prettyPrint$323ca37cb40f93d3(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_TypeNode__5fc$method$qualifier$06dc7ae4d27ad6a5(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_ast_TypeNode__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_TypeNode__5fc$method$type$b7282830a20ab2a3(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_TypeNode__5fc$method$type$91eb2e23e16df17f(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_TypeNode__5fc$method_info$buildTypes$df90664105e3e235;
extern _jc_method _jc_polyglot_ext_jl_ast_TypeNode__5fc$method_info$prettyPrint$323ca37cb40f93d3;
extern _jc_method _jc_polyglot_ext_jl_ast_TypeNode__5fc$method_info$qualifier$06dc7ae4d27ad6a5;
extern _jc_method _jc_polyglot_ext_jl_ast_TypeNode__5fc$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_ext_jl_ast_TypeNode__5fc$method_info$type$b7282830a20ab2a3;
extern _jc_method _jc_polyglot_ext_jl_ast_TypeNode__5fc$method_info$type$91eb2e23e16df17f;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$vmethods {
	struct _jc_object	*(*buildTypes$df90664105e3e235)(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_polyglot_visit_TypeBuilder$object *) _JC_JCNI_ATTR;
	void	(*prettyPrint$323ca37cb40f93d3)(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_polyglot_util_CodeWriter$object *, struct _jc_polyglot_visit_PrettyPrinter$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*qualifier$06dc7ae4d27ad6a5)(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*type$b7282830a20ab2a3)(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*type$91eb2e23e16df17f)(_jc_env *, struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_TypeNode__5fc$vmethods	polyglot_ext_jl_ast_TypeNode__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_TypeNode__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_refs {
	struct _jc_object	*type;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$refs {
    _jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_refs	polyglot_ext_jl_ast_TypeNode__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_TypeNode__5fc$sub_nonrefs	polyglot_ext_jl_ast_TypeNode__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_TypeNode__5fc$object {
	_jc_polyglot_ext_jl_ast_TypeNode__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_TypeNode__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_TypeNode__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_TypeNode__5fc$vtype _jc_polyglot_ext_jl_ast_TypeNode__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_TypeNode__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_TypeNode__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_TypeNode__5fc_H_ */
